import { ReactElement } from 'react';

import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsHeroCardLevel2Props = {
    brandName: string;
    cardTitle: string;
    cardDescription: string;
    backgroundImageDetail: BynderImageDataType;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)`
    background-clip: border-box;
    display: flex;
    flex-direction: row;
    word-wrap: break-word;
    position: relative;
    overflow: hidden;
    height: 236px;
    max-width: 536px;
    .content {
        height: 100%;
        padding: 50px;
        display: flex;
        flex-direction: column;
        position: absolute;
        top: 0;
        left: 0;
        box-sizing: border-box;
    }
    .bg-image {
        object-fit: cover;
    }
    .brand-container {
        background-color: #fff;
        width: fit-content;
        padding-left: 10px;
        padding-right: 10px;
    }
    .body-title {
        font-size: 26px;
        line-height: 44px;
        margin-bottom: 5px;
    }
    .body-text {
        font-size: 12px;
        font-weight: 700;
        margin-bottom: 5px;
    }
    @media (max-width:768px) {
        .content {
            padding: 5%;
        }
    }
`

const NsHeroCardLevel2 = ({
    brandName,
    cardTitle,
    cardDescription,
    backgroundImageDetail,
    button,
    className,
}: NsHeroCardLevel2Props): ReactElement => {
    return (
        <CardContainer className={className} data-testid="hero-card-level-2">
            <BynderMedia className="bg-image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <div className="brand-container">
                    <article>{brandName}</article>
                </div>
                <article className="body-title">{cardTitle}</article>
                <article className="body-text">{cardDescription}</article>
                <div>{button ? <CardButton {...button} /> : null}</div>
            </div>
        </CardContainer>
    );
};
export default NsHeroCardLevel2;
